@@ -65,34 +65,46 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#serviceresourcetablescollection)
     """
 
     def all(self) -> "ServiceResourceTablesCollection":
-        pass
+        """
+        Get all items from the collection, optionally with a custom page size and item count limit.
+        """
 
     def filter(  # type: ignore
         self, *, ExclusiveStartTableName: str = None, Limit: int = None
     ) -> "ServiceResourceTablesCollection":
-        pass
+        """
+        Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
+        """
 
     def limit(self, count: int) -> "ServiceResourceTablesCollection":
-        pass
+        """
+        Return at most this many Tables.
+        """
 
     def page_size(self, count: int) -> "ServiceResourceTablesCollection":
-        pass
+        """
+        Fetch at most this many Tables per service request.
+        """
 
     def pages(self) -> Iterator[List["Table"]]:
-        pass
+        """
+        A generator which yields pages of Tables.
+        """
 
     def __iter__(self) -> Iterator["Table"]:
-        pass
+        """
+        A generator which yields Tables.
+        """
 
 
 class Table(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#table)
     """
 
@@ -123,7 +135,7 @@ class Table(Boto3ServiceResource):
         """
         Create a batch writer object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablebatch_writer-method)
         """
 
@@ -131,7 +143,7 @@ class Table(Boto3ServiceResource):
         """
         The `DeleteTable` operation deletes a table and all of its items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.delete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete-method)
         """
 
@@ -187,7 +199,7 @@ class Table(Boto3ServiceResource):
         """
         Deletes a single item in a table by primary key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete_item-method)
         """
 
@@ -195,7 +207,7 @@ class Table(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_available_subresources-method)
         """
 
@@ -231,7 +243,7 @@ class Table(Boto3ServiceResource):
         The `GetItem` operation returns a set of attributes for the item with the given
         primary key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_item-method)
         """
 
@@ -240,7 +252,7 @@ class Table(Boto3ServiceResource):
         Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
         Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableload-method)
         """
 
@@ -296,7 +308,7 @@ class Table(Boto3ServiceResource):
         """
         Creates a new item, or replaces an old item with a new item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.put_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableput_item-method)
         """
 
@@ -359,7 +371,7 @@ class Table(Boto3ServiceResource):
         """
         The `Query` operation finds items based on primary key values.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablequery-method)
         """
 
@@ -368,7 +380,7 @@ class Table(Boto3ServiceResource):
         Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
         Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablereload-method)
         """
 
@@ -431,7 +443,7 @@ class Table(Boto3ServiceResource):
         The `Scan` operation returns one or more items and item attributes by accessing
         every item in a table or a secondary index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablescan-method)
         """
 
@@ -450,7 +462,7 @@ class Table(Boto3ServiceResource):
         Modifies the provisioned throughput settings, global secondary indexes, or
         DynamoDB Streams settings for a given table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate-method)
         """
 
@@ -509,7 +521,7 @@ class Table(Boto3ServiceResource):
         Edits an existing item's attributes, or adds a new item to the table if it does
         not already exist.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.update_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate_item-method)
         """
 
@@ -517,7 +529,7 @@ class Table(Boto3ServiceResource):
         """
         Waits until this Table is exists.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_exists-method)
         """
 
@@ -525,7 +537,7 @@ class Table(Boto3ServiceResource):
         """
         Waits until this Table is not exists.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_not_exists-method)
         """
 
@@ -535,7 +547,7 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.ServiceResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
     """
 
@@ -545,7 +557,7 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         """
         Creates a Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcetable-method)
         """
 
@@ -559,7 +571,7 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         The `BatchGetItem` operation returns the attributes of one or more items from
         one or more tables.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_get_item-method)
         """
 
@@ -574,7 +586,7 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         The `BatchWriteItem` operation puts or deletes multiple items in one or more
         tables.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_write_item-method)
         """
 
@@ -595,7 +607,7 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         """
         The `CreateTable` operation adds a new table to your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcecreate_table-method)
         """
 
@@ -603,6 +615,6 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourceget_available_subresources-method)
         """
